@@ -26,10 +26,18 @@ sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__),
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
-    'sphinx.ext.autodoc',
     'openstackdocstheme',
+    'sphinxcontrib.apidoc',
 ]
 
+# sphinxcontrib.apidoc options
+apidoc_module_dir = '../../glanceclient'
+apidoc_output_dir = 'reference/api'
+apidoc_excluded_paths = [
+    'tests/*',
+    'tests']
+apidoc_separate_modules = True
+
 # openstackdocstheme options
 repository_name = 'openstack/python-glanceclient'
 bug_project = 'python-glanceclient'
@@ -76,7 +84,6 @@ html_theme_path = [openstackdocstheme.get_html_theme_path()]
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
 
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
 
 # -- Options for man page output ----------------------------------------------
 
