@@ -16,7 +16,6 @@
 import copy
 import json
 import jsonpatch
-import six
 import warlock.model as warlock
 
 
@@ -31,12 +30,12 @@ class SchemaBasedModel(warlock.Model):
     """
 
     def _make_custom_patch(self, new, original):
-        if 'tags' in new and 'tags' not in original:
+        if not self.get('tags'):
+            tags_patch = []
+        else:
             tags_patch = [{"path": "/tags",
                            "value": self.get('tags'),
                            "op": "replace"}]
-        else:
-            tags_patch = []
 
         patch_string = jsonpatch.make_patch(original, new).to_string()
         patch = json.loads(patch_string)
@@ -51,10 +50,13 @@ class SchemaBasedModel(warlock.Model):
         original = copy.deepcopy(self.__dict__['__original__'])
         new = dict(self)
         if self.schema:
-            for (name, prop) in six.iteritems(self.schema['properties']):
+            for (name, prop) in self.schema['properties'].items():
                 if (name not in original and name in new and
                         prop.get('is_base', True)):
                     original[name] = None
+
+        original['tags'] = None
+        new['tags'] = None
         return self._make_custom_patch(new, original)
 
 
